@@ -128,6 +128,23 @@ class Test_validate_filename:
         validate_filename(value, platform)
         assert is_valid_filename(value, platform=platform)
 
+    @pytest.mark.parametrize(
+        ["platform"],
+        [["linux"], ["macos"], ["posix"]],
+    )
+    def test_normal_only_whitespaces(self, platform):
+        value = "  "
+        validate_filename(value, platform)
+        assert is_valid_filename(value, platform=platform)
+
+    def test_abnormal_only_whitespaces(self):
+        value = "  "
+        platform = "windows"
+        with pytest.raises(ValidationError) as e:
+            validate_filename(value, platform=platform)
+            assert e.value.reason == ErrorReason.NULL
+        assert not is_valid_filename(value, platform)
+
     @pytest.mark.parametrize(
         ["value", "platform"],
         chain.from_iterable(
@@ -179,7 +196,10 @@ class Test_validate_filename:
         assert e.value.reason == expected
 
     @pytest.mark.parametrize(
-        ["value", "platform", "max_len", "expected"], [["invalid_max_len", None, 0, ValueError],],
+        ["value", "platform", "max_len", "expected"],
+        [
+            ["invalid_max_len", None, 0, ValueError],
+        ],
     )
     def test_abnormal_max_len(self, value, platform, max_len, expected):
         with pytest.raises(expected):
@@ -269,7 +289,10 @@ class Test_validate_filename:
             [reserved_keyword, platform, None]
             for reserved_keyword, platform in product([".", ".."], ["posix", "linux", "macos"])
         ]
-        + [[":", "posix", ValidationError], [":", "macos", ValidationError],],
+        + [
+            [":", "posix", ValidationError],
+            [":", "macos", ValidationError],
+        ],
     )
     def test_exception_reserved_name(self, value, platform, expected):
         if expected is None:
@@ -403,7 +426,11 @@ class Test_sanitize_filename:
         assert is_valid_filename(sanitized_name)
 
     @pytest.mark.parametrize(
-        ["value", "expected"], [["", ""], [None, ""],],
+        ["value", "expected"],
+        [
+            ["", ""],
+            [None, ""],
+        ],
     )
     def test_normal_null_values(self, value, expected):
         assert sanitize_filename(value) == expected
@@ -455,7 +482,11 @@ class Test_sanitize_filename:
         assert is_valid_filename(filename, platform=test_platform)
 
     @pytest.mark.parametrize(
-        ["value", "check_reserved", "expected"], [["CON", True, "CON_"], ["CON", False, "CON"],]
+        ["value", "check_reserved", "expected"],
+        [
+            ["CON", True, "CON_"],
+            ["CON", False, "CON"],
+        ],
     )
     def test_normal_check_reserved(self, value, check_reserved, expected):
         assert (
